@@ -16,6 +16,7 @@ echo 'single quoted string'
 echo "double quoted string"
 echo $'string with esc\apes\x0din it'
 echo $"string meant to be translated"
+echo "$"
 
 
 # comments:
@@ -30,6 +31,10 @@ mkdir this\\ #is a comment
 
 # brace expansion
 mv my_file.{JPG,jpg}
+echo f.{01..100..3} f.{Z..a..-3}
+echo f.{01..100} f.{a..Z}
+# no brace expansion
+echo f.{..100} f.{1..Z} f.{a..Z..}
 
 
 # special characters are escaped:
@@ -187,6 +192,10 @@ You're right, this is definitely no bash code
 But ls more $parameters should be expanded. :->
 EOF
 
+cat <<bla || exit
+bla bla
+bla
+
 
 # indented:
 if true
@@ -200,10 +209,13 @@ elif [ -d $file ]; then
 	EOF
 fi
 
+if ! { cmd1 && cmd2 ; }; then echo ok ; fi
+if ! cmd1 arg; then echo ok ; fi
 
 case 1 in
 2) echo xxx;
 ;;
+?) foo || yyy ; foo abc || echo abc ;;
 1) echo yyy;
 esac
 
@@ -225,6 +237,8 @@ pacman -syu --needed intel-ucode grub
 [[ $name =~ (.*)_(S[0-9]{2})(E[0-9]{2,3}[a-z]{0,1})_(.*) ]]
 rm /data/{hello1,hello2}/input/{bye1,$bye2}/si{a,${b},c{k,p{e,a}}}/*.non
 rm /data/{aa,{e,i}t{b,c} # Not closed
+rm /data/{aa,{e,i}t{b,c}}
+rm /data/{aa,{i}}
 rm /data{aa{bb{cc{dd}}}}
 rm /data{aaa`aaa}aa`aaa}a
 
@@ -279,7 +293,7 @@ opt param#nocomment ab'a'cd [[ param ]] } { ~a .a #comments
 path path/file dir/ / // 3/f a@/ 'a'/b d/'a'b a\ d/f f/f\
 ile
 path ~ ~/ ~a/ . .. ./a ../a
-path /path/* /path/f* /path/f@ /path/f@(|)
+path /path/* /path/f* /path/f@ /path/f@(|) {a/b} a{b}/c a/b{c} a/{b} a/{b}c
 glob ? * ?f *f f* f? **/ ~/* ~* /path/f* 'a'* 'a'f/?
 extglob @ @(*) @(f*|f??(f)) f!(+(?(@(*(f)f)f)f)f)f @'a'@(|) a@(?)
 subs f! f!! f!s 'a'!s \( $v {a,b} {a} {a}/d {a\,} {a,} {a,\},b} ds/{a,b}sa/s
@@ -369,6 +383,14 @@ echo ${a^^l*} ${a,} ${!a} ${#a[1]} ${a:1:$b} $((++i,i--))
 [[ a <b ]]
 [[ a< b ]]
 [[ a < b ]]
+[[(! -d .)]]
+[[ ! -d . ]]
+[[ !(-d .) ]]
+[[ -f a || -f b ]]
+[[ -f a||-f b ]]
+[ -d `echo .`] ]
+[[ -d `echo .`]] ]]
+[[ a != b && ${a}a = b${b} ]]
 
 ((3+1+a+$c*(x) & 0x43422fd+03-085/23#D9a@_^8))
 { echo
@@ -387,6 +409,8 @@ test a -eq b
 a() { echo x; }
 a  () { echo x; }
 function f { echo x; }
+kde.org() { echo x; }
+--func() { echo x; }
 
 # variables
 a=(a b c)
@@ -398,6 +422,9 @@ a[$((
     2+4
 ))]='x'
 a=([a]=2 `echo` -s > 'ds')
+a=(#comment
+value#nocomment #comment)
+)
 a=a cat
 a=`ls` cat
 
@@ -429,5 +456,14 @@ case a in
   a\( | b*c? ) echo
   (b$c) # no pattern
   ;;
+  (b$c) ;;
+  # no pattern
   (b$c)
 esac
+
+case "$1" in
+ "a") run_a|&a;;
+ "b") run_b;;
+ "c") run_c;;
+ *) echo "Plase choose between 'a', 'b' or 'c'" && exit 1;;
+esac
